#
# spec file for package python-nbsphinx
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-nbsphinx
Version:        0.6.1
Release:        bp153.1.17
Summary:        Jupyter Notebook Tools for Sphinx
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/spatialaudio/nbsphinx/
Source:         https://files.pythonhosted.org/packages/source/n/nbsphinx/nbsphinx-%{version}.tar.gz
BuildRequires:  %{python_module Send2Trash}
BuildRequires:  %{python_module Sphinx >= 1.3.2}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
Requires:       python-Send2Trash
Requires:       python-Sphinx >= 1.3.2
Requires:       python-docutils
Requires:       python-nbconvert
Requires:       python-nbformat
Requires:       python-sphinx_rtd_theme
Recommends:     mathjax
Recommends:     pandoc
Provides:       python-jupyter_nbsphinx = %{version}
Obsoletes:      python-jupyter_nbsphinx < %{version}
BuildArch:      noarch
%ifpython3
Provides:       jupyter-nbsphinx = %{version}
%endif
%python_subpackages

%description
The nbsphinx package is a Sphinx extension that provides a source
parser for *.ipynb files. Custom Sphinx directives are used to show
Jupyter Notebook code cells (and of course their results) in both HTML
and LaTeX output. Un-evaluated notebooks – i.e. notebooks without
stored output cells – will be automatically executed during the Sphinx
build process.

%prep
%setup -q -n nbsphinx-%{version}

%build
%python_build

%install
%python_install

%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{fdupes %{buildroot}%{_jupyter_prefix} %{buildroot}%{python_sitelib}}

%files %{python_files}
%doc NEWS.rst README.rst
%license LICENSE
%{python_sitelib}/nbsphinx.py*
%pycache_only %{python_sitelib}/__pycache__/nbsphinx.*.py*
%{python_sitelib}/nbsphinx-%{version}-py*.egg-info

%changelog
* Sat May  2 2020 Arun Persaud <arun@gmx.de>
- update to version 0.6.1:
  * .ipynb_checkpoints is automatically added to exclude_patterns
- changes from version 0.6.0:
  * Thumbnail galleries (inspired by
    https://sphinx-gallery.github.io/)
  * nbsphinx-toctree as cell tag
  * Keyword arguments in nbsphinx_custom_formats
  * Python 2 support has been dropped
* Mon Feb 10 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.5.1
  * This will be the last release supporting Python 2.x!
  * Support for https://github.com/choldgraf/sphinx-copybutton
  * Executed notebooks are now saved in the HTML output directory
* Wed Jan 15 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.5.0
  * Automatic support for Jupyter widgets,
    customizable with nbsphinx_widgets_path\
    (and nbsphinx_widgets_options)
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- Latest release drops python2 support.
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.4.3
  * Add option nbsphinx_requirejs_path (and nbsphinx_requirejs_options)
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.4.2
  * Re-establish Python 2 compatibility (but the clock is ticking ...)
- Rename to to match python package naming guidelines.
- Split jupyter components into own subpackage.
* Mon Feb 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop dependency on deprecated python-py package as it is not
  stated anywhere in the upstream sources
* Mon Jan  7 2019 Todd R <toddrme2178@gmail.com>
- This is python3-only.
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to Version 0.4.1
  * Fix issue #266
- Update to Version 0.4.0
  * Support for "data-cite" HTML tags in Markdown cells
  * Add option ``nbsphinx_custom_formats``
  * LaTeX macros ``\nbsphinxstartnotebook`` and ``\nbsphinxstopnotebook``
  * Support for cell attachments
  * Add options ``nbsphinx_input_prompt`` and ``nbsphinx_output_prompt``
  * Re-design LaTeX output of code cells, fix image sizes
* Fri Sep 28 2018 Todd R <toddrme2178@gmail.com>
- Update to 0.3.5
  * Disable nbconvert version 5.4 to avoid jupyter/nbconvert#878
* Fri Sep  7 2018 toddrme2178@gmail.com
- Update to 0.3.4
  * Fix issue #196 and other minor changes
* Sat Apr 28 2018 toddrme2178@gmail.com
- Update to version 0.3.3
  * Locally linked files are only copied for Jupyter notebooks
    (and not anymore for other Sphinx source files)
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to version 0.3.2
  * Links to local files are rewritten for all Sphinx source files (not only
    Jupyter notebooks)
* Thu Jan 18 2018 toddrme2178@gmail.com
- Update to version 0.3.1
  * Enable notebook translations (NB: The use of reST strings is temporary!)
- Update to version 0.3.0
  * Add options ``nbsphinx_prolog`` and ``nbsphinx_epilog``
  * Links from ``*.rst`` files to notebooks have to start with a slash
* Sun Dec  3 2017 arun@gmx.de
- update to version 0.2.18:
  * Fix issue #148
* Tue Nov 14 2017 arun@gmx.de
- update to version 0.2.17:
  * Fix issue #146
- changes from version 0.2.16:
  * Fix issue #142
- changes from version 0.2.15 :
  * Links to subsections are now possible in all source files
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to 0.2.14
  * Add option ``nbsphinx_kernel_name``
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Initial version.
